Crate objc2_file_provider_ui

Crate objc2_file_provider_ui 

Bindings to the FileProviderUI framework

See Apple’s docs and the general docs on framework crates for more information.

Structs

FPUIActionExtensionContextFPUIActionExtensionContext
An extension context provided to File Provider UI extensions.
FPUIActionExtensionViewControllermacOS and FPUIActionExtensionViewController and objc2-app-kit
The custom user interface used to perform a selected action.
FPUIExtensionErrorCodeFPUIActionExtensionContext
The error codes for errors raised by the File Provider UI extension.

Statics

FPUIErrorDomainFPUIActionExtensionContext
The error domain for errors raised by the File Provider UI extension.

Type Aliases

FPUIActionIdentifierFPUIActionExtensionContext
Apple’s documentation